1.0.0 API documentation: GLM_GTX_matrix_transform_2d

| 1.0.0 API documentation

Functions
GLM_GTX_matrix_transform_2d
Experimental extensions

## Functions
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | rotate (mat< 3, 3, T, Q > const &m, T angle)
| Builds a rotation 3 * 3 matrix created from an angle. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | scale (mat< 3, 3, T, Q > const &m, vec< 2, T, Q > const &v)
| Builds a scale 3 * 3 matrix created from a vector of 2 components. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | shearX (mat< 3, 3, T, Q > const &m, T y)
| Builds an horizontal (parallel to the x axis) shear 3 * 3 matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | shearY (mat< 3, 3, T, Q > const &m, T x)
| Builds a vertical (parallel to the y axis) shear 3 * 3 matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_QUALIFIER mat< 3, 3, T, Q > | translate (mat< 3, 3, T, Q > const &m, vec< 2, T, Q > const &v)
| Builds a translation 3 * 3 matrix created from a vector of 2 components. More...

## Detailed Description

Include <glm/gtx/matrix_transform_2d.hpp> to use the features of this extension.

Defines functions that generate common 2d transformation matrices.

## Function Documentation

## ◆ rotate()

GLM_FUNC_QUALIFIER mat<3, 3, T, Q> glm::rotate | ( | mat< 3, 3, T, Q > const & | m,
|  | T | angle
| ) |  |

Builds a rotation 3 * 3 matrix created from an angle.

Parameters

  m | Input matrix multiplied by this translation matrix.
  angle | Rotation angle expressed in radians.

## ◆ scale()

GLM_FUNC_QUALIFIER mat<3, 3, T, Q> glm::scale | ( | mat< 3, 3, T, Q > const & | m,
|  | vec< 2, T, Q > const & | v
| ) |  |

Builds a scale 3 * 3 matrix created from a vector of 2 components.

Parameters

  m | Input matrix multiplied by this translation matrix.
  v | Coordinates of a scale vector.

## ◆ shearX()

GLM_FUNC_QUALIFIER mat<3, 3, T, Q> glm::shearX | ( | mat< 3, 3, T, Q > const & | m,
|  | T | y
| ) |  |

Builds an horizontal (parallel to the x axis) shear 3 * 3 matrix.

Parameters

  m | Input matrix multiplied by this translation matrix.
  y | Shear factor.

## ◆ shearY()

GLM_FUNC_QUALIFIER mat<3, 3, T, Q> glm::shearY | ( | mat< 3, 3, T, Q > const & | m,
|  | T | x
| ) |  |

Builds a vertical (parallel to the y axis) shear 3 * 3 matrix.

Parameters

  m | Input matrix multiplied by this translation matrix.
  x | Shear factor.

## ◆ translate()

GLM_FUNC_QUALIFIER mat<3, 3, T, Q> glm::translate | ( | mat< 3, 3, T, Q > const & | m,
|  | vec< 2, T, Q > const & | v
| ) |  |

Builds a translation 3 * 3 matrix created from a vector of 2 components.

Parameters

  m | Input matrix multiplied by this translation matrix.
  v | Coordinates of a translation vector.